export interface Pojo {
    [propName: string]: any;
}
export declare namespace Hydride {
    interface Props {
        [propName: string]: any;
        h?: any;
        children?: any;
    }
    interface Store {
        renderTrigger: any;
        jsxFactory: any;
        receiveUpdateFromParent: (updatedState: Pojo) => void;
        dispatch: (action: {
            type: string;
            payload?: any;
        }) => void;
        subscribe: (handler: (state: Pojo) => void) => () => void;
        getState: () => any;
    }
    interface Action {
        type: string;
        payload?: any;
    }
}
export interface BaseComponentProps extends Hydride.Props {
    key: string;
    store?: {
        initialState: Pojo;
        reducers: any;
        middlewares?: Pojo;
    };
}
export interface StoreParams {
    reducers: any;
    renderTrigger: any;
    jsxFactory: any;
    initialState: Pojo;
    middlewares?: any[];
}
export default abstract class Component<Props extends BaseComponentProps, State extends Pojo = {}, StateTree extends Pojo = {}> {
    /** Array of class-based child components */
    childComponents: {
        [childKey: string]: Component<BaseComponentProps, Pojo, Pojo>;
    };
    /** Props passed into the component */
    props: Props;
    /** Internal component state */
    state: State;
    /** The entire state tree for the current store */
    stateTree: StateTree;
    /** The component's store, which is shared by all components in the scope */
    private store;
    constructor(store: Hydride.Store, props: Props);
    /** Returns a VNode, needs to be implemented by component creator */
    abstract render(): void;
    /** h function required to render child components */
    h(element: string | any, properties?: any, children?: any): any;
    /** Called before a component's props are updated. */
    componentWillReceiveProps(nextProps: Props): void;
    /** Updates the private state of the component */
    setState(newState: Partial<State>): void;
    /** Dispatches an action to the component's store */
    dispatch(action: any): void;
    /** Used behind the scenes to sync a component's storeState with the store state */
    private updateStateTree(nextState);
}
/** Creates a new store of application state */
export declare function newStore(p: StoreParams): any;
/** Combines reducers to allow composition */
export declare function combineReducers(reducers: any): (state: {} | undefined, action: any) => {};
